@@ -1,12 +1,3 @@
-#  File tests/normal.R in package latentnet, part of the Statnet suite
-#  of packages for network analysis, http://statnet.org .
-#
-#  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) at
-#  http://statnet.org/attribution
-#
-#  Copyright 2003-2014 Statnet Commons
-#######################################################################
 library(latentnet)
 opttest({
 n<-20
@@ -26,7 +17,7 @@ dm<--as.matrix(dist(Z))
 ym<-rnorm(n*n,2+dm,sqrt(y.var))
 
 set.edge.value(y,"v",ym)
-image(getYm(y,"v"))
+image(as.matrix(y,a="v",m="a"))
 y.fit<-ergmm(y~euclidean(d=2,G=2),response="v",family="normal",fam.par=list(prior.var=y.var.prior,prior.var.df=2),verbose=TRUE)
 
 Z.mkl<-plot(y.fit,Z.ref=Z)
@@ -41,7 +32,7 @@ dm<-tcrossprod(Z)
 ym<-rnorm(n*n,2+dm,sqrt(y.var))
 
 set.edge.value(y,"v",ym)
-image(getYm(y,"v"))
+image(as.matrix(y,a="v",m="a"))
 y.fit<-ergmm(y~bilinear(d=2,G=2),response="v",family="normal",fam.par=list(prior.var=y.var.prior,prior.var.df=2),verbose=TRUE)
 
 Z.mkl<-plot(y.fit,Z.ref=Z)
@@ -53,7 +44,7 @@ cat("No latent space:\n")
 
 ym<-rnorm(n*n,0,sqrt(y.var))
 set.edge.value(y,"v",ym)
-image(getYm(y,"v"))
+image(as.matrix(y,a="v",m="a"))
 y.fit<-ergmm(y~1,response="v",family="normal",fam.par=list(prior.var=y.var.prior,prior.var.df=2),verbose=TRUE)
 summary(y.fit)
 
